#
# spec file for package sdbootutil
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sdbootutil
Version:        1+git20241217.5aeb4e9
Release:        1.1
Summary:        bootctl wrapper for BLS boot loaders
License:        MIT
URL:            https://github.com/openSUSE/sdbootutil
Source:         %{name}-%{version}.tar
BuildRequires:  systemd-rpm-macros
Requires:       dialog
Requires:       dracut-pcr-signature
Requires:       efibootmgr
Requires:       jq
Requires:       pcr-oracle
Requires:       qrencode
Requires:       sed
Requires:       (%{name}-snapper if (snapper and btrfsprogs))
Requires:       (%{name}-tukit if read-only-root-fs)
# While systemd-pcrlock is in experimental
Requires:       systemd-experimental
# something needs to require it. Can be us.
Requires:       tpm2.0-tools
# While bootctl is in udev
Requires:       udev
Supplements:    (grub2-x86_64-efi-bls and shim)
Supplements:    (systemd-boot and shim)
ExclusiveArch:  aarch64 ppc64le riscv64 x86_64
%{?systemd_requires}

%description
bootctl wrapper for BLS boot loaders, like systemd-boot and grub2-bls.
Implements also the life cycle of a full disk encryption installation,
based on systemd.

%package snapper
Summary:        plugin script for snapper
Requires:       %{name} = %{version}
Requires:       btrfsprogs
Requires:       snapper

%description snapper
Plugin scripts for snapper to handle BLS config files

%package tukit
Summary:        plugin script for tukit
Requires:       %{name} = %{version}
Requires:       tukit

%description tukit
Plugin scripts for tukit to handle BLS config files

%package kernel-install
Summary:        Hook script for kernel-install
Requires:       %{name} = %{version}
# While kernel-install is in udev
Requires:       udev

%description kernel-install
Plugin script for kernel-install. Note: installation of this
package may disable other plugin scripts that are incompatible.

%package enroll
Summary:        Full disk encryption enrollment
Requires:       %{name} = %{version}

%description enroll
Systemd service and script for full disk encryption enrollment.

%package jeos-firstboot-enroll
Summary:        JEOS module for full disk encryption enrollment
Requires:       %{name} = %{version}
Requires:       %{name}-enroll = %{version}
Requires:       jeos-firstboot

%description jeos-firstboot-enroll
JEOS module for full disk encryption enrollment. The module
present the different options and delegate into sdbootutil-enroll
service the effective enrollment.

%prep
%setup -q

%build

%install
install -D -m 755 %{name} %{buildroot}%{_bindir}/%{name}

# Update prediction service
install -D -m 644 %{name}-update-predictions.service \
	%{buildroot}%{_unitdir}/%{name}-update-predictions.service

# Enrollment service
install -m 755 %{name}-enroll %{buildroot}%{_bindir}/%{name}-enroll
install -D -m 644 %{name}-enroll.service %{buildroot}/%{_unitdir}/%{name}-enroll.service

# Jeos module
install -D -m 644 jeos-firstboot-enroll-override.conf \
	%{buildroot}%{_prefix}/lib/systemd/system/jeos-firstboot.service.d/jeos-firstboot-enroll-override.conf
install -D -m 644 jeos-firstboot-enroll %{buildroot}%{_datadir}/jeos-firstboot/modules/enroll

# Snapper
install -D -m 755 10-%{name}.snapper %{buildroot}%{_prefix}/lib/snapper/plugins/10-%{name}.snapper

# Tukit
install -D -m 755 10-%{name}.tukit %{buildroot}%{_prefix}/lib/tukit/plugins/10-%{name}.tukit

# kernel-install
install -D -m 755 50-%{name}.install %{buildroot}%{_prefix}/lib/kernel/install.d/50-%{name}.install

# tmpfiles
install -D -m 755 kernel-install-%{name}.conf \
	%{buildroot}%{_prefix}/lib/tmpfiles.d/kernel-install-%{name}.conf

%transfiletriggerin -- %{_prefix}/lib/systemd/boot/efi %{_datadir}/grub2/%{_build_arch}-efi %{_datadir}/efi/%{_build_arch}
cat > /dev/null || :
[ "$YAST_IS_RUNNING" != 'instsys' ] || exit 0
[ -e /sys/firmware/efi/efivars ] || exit 0
[ -z "$TRANSACTIONAL_UPDATE" ] || exit 0
[ -z "$VERBOSE_FILETRIGGERS" ] || echo "%{name}-%{version}-%{release}: updating bootloader"
sdbootutil update

%preun
%service_del_preun %{name}-update-predictions.service

%postun
%service_del_postun %{name}-update-predictions.service

%pre
%service_add_pre %{name}-update-predictions.service

%post
%service_add_post %{name}-update-predictions.service

%preun enroll
%service_del_preun %{name}-enroll.service

%postun enroll
%service_del_postun %{name}-enroll.service

%pre enroll
%service_add_pre %{name}-enroll.service

%post enroll
%service_add_post %{name}-enroll.service

%posttrans kernel-install
%tmpfiles_create kernel-install-%{name}.conf

%files
%license LICENSE
%{_bindir}/%{name}
%{_unitdir}/%{name}-update-predictions.service

%files snapper
%dir %{_prefix}/lib/snapper
%dir %{_prefix}/lib/snapper/plugins
%{_prefix}/lib/snapper/plugins/*

%files tukit
%dir %{_prefix}/lib/tukit
%dir %{_prefix}/lib/tukit/plugins
%{_prefix}/lib/tukit/plugins/*

%files kernel-install
%dir %{_prefix}/lib/kernel
%dir %{_prefix}/lib/kernel/install.d
%{_prefix}/lib/kernel/install.d/*
%{_prefix}/lib/tmpfiles.d/kernel-install-%{name}.conf

%files enroll
%{_bindir}/%{name}-enroll
%{_unitdir}/%{name}-enroll.service

%files jeos-firstboot-enroll
%dir %{_datadir}/jeos-firstboot
%dir %{_datadir}/jeos-firstboot/modules
%{_datadir}/jeos-firstboot/modules/enroll
%dir %{_unitdir}/jeos-firstboot.service.d
%{_unitdir}/jeos-firstboot.service.d/jeos-firstboot-enroll-override.conf

%changelog
* Tue Dec 17 2024 aplanas@suse.com
- Update to version 1+git20241217.5aeb4e9:
  * Use only the first output line of findmount in free space calc
* Tue Dec 17 2024 aplanas@suse.com
- Update to version 1+git20241217.1370153:
  * Add trigger for grub2-bls
* Fri Dec  6 2024 aplanas@suse.com
- Update to version 1+git20241206.dccea55:
  * Fix quotes in bind mount command (bsc#1233378)
  * Allow multiple entries for initial measurements
* Tue Nov 26 2024 aplanas@suse.com
- Update to version 1+git20241126.83ebe2c:
  * Fix help for get-timeout
  * Add get default and timeout
  * Replace -a with &&
  * Drop PATH field
  * sdbootutil-enroll: harden script against unexpected conditions
* Mon Nov 18 2024 aplanas@suse.com
- Update to version 1+git20241118.23c1900:
  * Fix missing grep file
  * Detect new bootctl error message
  * If BLI is not active use the loader.conf
* Tue Nov 12 2024 aplanas@suse.com
- Update to version 1+git20241112.ecf5f97:
  * Move enrollment from disk-encryption-tool
  * Use [/usr]/etc/default/fde-tools as config file
* Thu Nov  7 2024 aplanas@suse.com
- Update to version 1+git20241107.6f81ff3:
  * Add list-devices command
  * Ignore devices with x-sdbootutil.ignore mark
  * Quote variable expansion
  * Support empty crypttab options
* Thu Nov  7 2024 aplanas@suse.com
- Update to version 1+git20241107.542aa84:
  * Fix missing timeout parameter
* Tue Nov  5 2024 aplanas@suse.com
- Update to version 1+git20241105.3404bf8:
  * Do a cleanup before making free space
  * Simplify unlock mechanism and recovery key enroll
  * Drop generate-pin parameter
  * Indentation and comments fix
  * Measure grubenv
  * Add set-default and set-timout commands
  * rollback bootloader after setting default snapshot
  * Improve error checking and fix small bugs
  * Add --unlock argument
  * Use unique names for the kernel keyring
  * Add --generate-pin to generate a recovery PIN
  * Enroll a new recovery key
  * Bind mount snapshot dir onto itself before chroot.
* Thu Oct 17 2024 aplanas@suse.com
- Update to version 1+git20241017.34ee974:
  * Keep SELinux label of /etc/crypttab intact when changing options
    (boo#1231696)
  * Fix typo in update-entry help, should be  /etc/kernel/cmdline
* Tue Oct  8 2024 aplanas@suse.com
- Update to version 1+git20241008.3df16d2:
  * Improve not found bootloader error msg
* Mon Oct  7 2024 aplanas@suse.com
- Update to version 1+git20241007.192698c:
  * Translate GRUB2 architecture name
* Fri Oct  4 2024 aplanas@suse.com
- Update to version 1+git20241004.a1bb60f:
  * Support bootloader switch
  * Update order after bootloader install
  * Use /etc/sysconfig/bootloader to untie detection
  * Reference to grub2-bls
* Wed Oct  2 2024 aplanas@suse.com
- Update to version 1+git20241002.7da4a47:
  * Do not specify bootloader requirement
* Wed Oct  2 2024 aplanas@suse.com
- Update to version 1+git20241002.7b8957c:
  * Requires udev for bootctl
  * Use chroot instead of --sysroot in dracut
  * Replace cut with idiomatic code
  * Show recovery PIN generated by systemd-pcrlock
* Thu Sep 12 2024 aplanas@suse.com
- Update to version 1+git20240912.02d30ed:
  * Generate predictions for update_entry
* Thu Sep  5 2024 aplanas@suse.com
- Update to version 1+git20240905.e7ca8cf:
  * Replace root=UUID= with root=device
* Tue Sep  3 2024 aplanas@suse.com
- Update to version 1+git20240903.81f1f40:
  * Generate new predictions for update_all_entries
  * Use raw option in jq update all entries
* Fri Aug 30 2024 aplanas@suse.com
- Update to version 1+git20240830.7f696c8:
  * Use parameter "snapshot" instead the global one
  * Add update-entry and update-all-entries commands
  * Generate tpm2 public key before enroll_pcroracle
  * Fix function names for enrolling pcr-oracle
  * Check if enroll functions worked correctly
  * Warn when pcrlock.json or tpm2-pcr-signature.json are missing
* Thu Aug 29 2024 aplanas@suse.com
- Update to version 1+git20240829.1b5aa4d:
  * Add --default-snapshot parameter (bsc#1224773)
* Fri Aug 23 2024 aplanas@suse.com
- Update to version 1+git20240823.30ef4f1:
  * Remove the executed line in grub2bls
  * Support new grub2-bls package
* Thu Aug 22 2024 aplanas@suse.com
- Update to version 1+git20240822.bc7e06b:
  * Hide exit code for set-default-snapshot plugin call
* Mon Aug 12 2024 aplanas@suse.com
- Update to version 1+git20240812.ee2298f:
  * Use arg_no_reuse_initrd as update_initrd
  * Reorder PIN and PW search
  * fix portable installation The fallback.efi should not be added when installing in portable mode
  * Use /run for tmpfiles instead of /etc
* Mon Jul 22 2024 aplanas@suse.com
- Update to version 1+git20240722.e6d7c91:
  * Fix early return value when cleaning pcrlock.d
* Fri Jul 19 2024 aplanas@suse.com
- Update to version 1+git20240719.36c650f:
  * Remove pcrlock.d if there are too many files
  * Limit LAST_WORKING_SNAPSHOTS to 3
* Thu Jul 18 2024 aplanas@suse.com
- Update to version 1+git20240718.6fbaad1:
  * Enroll using pcr_oracle if pcrlock fails
  * Fix loader.conf measurement
  * Address some shellcheck issues
  * Implement basic [un]enroll commands
  * snapper: do not error if sdbootutil fails
* Tue Jul 16 2024 aplanas@suse.com
- Update to version 1+git20240716.bb40c38:
  * Add --only-default option for list-entries command
  * Turn off colors when the shell it not interactive
  * Support portable installation of bootloader This is useful to create portable drives, so the bootloader entry isn't created permenantly.
* Thu Jul  4 2024 aplanas@suse.com
- Update to version 1+git20240704.a2c5a26:
  * Complain if fde-tools is missing
  * Remove rpm scriptlets
  * Remove is_transactional check
  * Call regenerate-initrd-posttrans
  * Remove pcrlock files older than 1 week
  * Measure initial state from backup
  * Remove useless TODO comments
  * Rename variable to SDB_ADD_INITIAL_COMPONENT
  * Fix transactional check
  * Add system / snapper as prefix for tw/grub2-bls
  * Compose the entry file name in a single place
  * Make 'invert' a generic case
  * Make free space for new kernel / initrd
  * Replace match with test in jq
  * grub: add grub drive in initrd path
  * grub: blscfg is included in the image
  * Fix pcrlock_manual_raw call
  * Add emacs .dir-locals.el
  * Show success message
  * Use a recovery pin for re-enrollment
  * grub2: entries predictions as a single component
  * grub2: remove duplicate function
  * Add blscfg.mod in the ESP and update predictions
  * grub2: generate pcrlock predictions
  * Fix some typos
* Tue May 14 2024 lnussel@suse.com
- Update to version 1+git20240514.56dc89c:
  * Add show-entry command
  * Add SYSTEMD_COLORS flag
  * Add byte order mark to boot.csv
* Mon May  6 2024 lnussel@suse.com
- Update to version 1+git20240506.573a6a4:
  * Don't try to mess with overlayfs inside transaction
  * .spec - requires: dialog
* Wed Apr 10 2024 lnussel@suse.com
- Update to version 1+git20240410.3325802:
  * fallback for machine-id
* Mon Apr  8 2024 lnussel@suse.com
- Update to version 1+git20240408.49e4021:
  * Update requirements
  * Measure manually initrd if pcrlock fails
  * Set SYSTEMD_LOG_LEVEL if verbose
  * Only error out on empty machine-id when actually used
  * feat: add basic boot assessment
  * fix: use new os-release and machine-id files
  * dracut call: --add-device belongs to --sysroot
  * Make sdbootutil usable with no snapshot Systems
* Thu Mar 21 2024 lnussel@suse.com
- Update to version 1+git20240321.04bfbac:
  * Warning if make-policy do not register all PCRs
* Wed Mar 20 2024 lnussel@suse.com
- Update to version 1+git20240320.8b35615:
  * Revert "Remove GRUB2 package conflict"
* Thu Mar 14 2024 lnussel@suse.com
- Update to version 1+git20240314.3472899:
  * Add minimal grub configuration
  * Add systemd.machine_id to kernel command line
  * Add SNAPSHOT parameter to bootloader command
  * Remove GRUB2 package conflict
  * Resolve some shellcheck issues
  * Remove unused variable
  * Change tempfile name
  * needs-update and update meets grub2
  * Consider grub2 when installing the bootloader
  * Add grub2 detector and command
  * fix: delete correct initrd file after installation
  * feat: add add-all-kernels-clean function
  * refactor: use snapshot as argument for all commands
  * Set SYSTEMD_LOG_LEVEL=warning for pcrlock
  * Don't require /etc/sysconfig/fde-tools for pcr-oracle
  * add loader.conf to locking
  * Make sure there are actually entries
  * Prefer pcr-oracle if it's actually configured
  * Don't log to syslog ourselves
  * Fix typo
  * fix: remove Tumbleweed version from regular entries
* Thu Feb 15 2024 lnussel@suse.com
- Update to version 1+git20240215.cb7e392:
  * Add --no-random-seed argument
* Wed Feb 14 2024 lnussel@suse.com
- Update to version 1+git20240214.ba81e0e:
  * Fix pcr-oracle use
  * Add device when generating initrd for snapshots
  * Use systemd-pcrlock
  * Pre-built initrd support
  * Add subvolumes_prefix support
* Tue Jan 23 2024 lnussel@suse.com
- Update to version 1+git20240122.c0d8f76:
  * Integrate with kernel-install
  * Rework kernel listing a bit
  * Add checks to list-entries
  * List entries for current system only by default
  * Fall back to loader.conf if setting efivar failed
  * Runtime determine kernel image name
  * Add list-snapshots
  * Add list-entries command
* Mon Jan 22 2024 lnussel@suse.com
- Update to version 1+git20240118.7e744b4:
  * Bind mount /etc inside the snapshot
* Thu Dec 21 2023 lnussel@suse.com
- Update to version 1+git20231221.42797ab:
  * Do not fail if LUKS2 section is empty
* Thu Dec 14 2023 lnussel@suse.com
- Update to version 1+git20231214.b186b2d:
  * Fix exit code
  * Revert "Add pcr predictions to initrd for now"
* Wed Dec 13 2023 lnussel@suse.com
- Update to version 1+git20231213.2a07af6:
  * Add update-predictions command
  * Predict all the entries
* Mon Dec 11 2023 lnussel@suse.com
- Update to version 1+git20231211.01c6a76:
  * Add ExclusiveArch for 64-bit EFI architectures
* Wed Nov 29 2023 lnussel@suse.com
- Update to version 1+git20231129.d7f3909:
  * Add pcr predictions to initrd for now
  * Generate new TPM2 predictions with pcr-oracle
  * Update file triggers
  * Fix exit code of update command
  * Add a %%transfiletriggerin to update EFI binaries
  * Update help text
* Tue Nov 14 2023 lnussel@suse.com
- Update to version 1+git20231114.6bcf1d3:
  * Fix quoting when calling dracut
* Thu Nov  2 2023 lnussel@suse.de
- Update to version 1+git20231102.beb4c19:
  * Update sdboot in snapper hook
  * Install command with specific snapshot
  * Install sdbootutil marker next to loader
  * In t-u mode, don't call sdbootutil in rpm scriptlets
* Thu Oct 26 2023 lnussel@suse.com
- Update to version 1+git20231026.f43c33c:
  * Fix generating initrd for random snapshots
* Mon Oct 23 2023 lnussel@suse.de
- Update to version 1+git20231023.873adb9:
  * Use correct image name on aarch64
* Thu Oct 19 2023 Fabian Vogt <fvogt@suse.de>
- Add changes from gh#openSUSE/sdbootutil#21:
  * sdbootutil.spec: Add missing efibootmgr dependency
  * sdbootutil.spec: Make sdbootutil-snapper a hard dependency
* Thu Oct 12 2023 lnussel@suse.de
- Update to version 1+git20231005.890f70c:
  * Add --no-reuse-initrd option
  * Refactor boot descriptive entries
  * feat: more descriptive bootmenu entries
  * Remove stray set -x
  * speed up snapper list
  * Fix misleading comment
  * Fix helptext
* Thu Aug 17 2023 lnussel@suse.de
- Update to version 1+git20230817.2a3cd34:
  * Ignore errors from efibootmgr
  * Update spec file
  * Add marker to flag installation using sdbootutil
  * Refactor and fix boot entry installation
  * Don't exit in warn()
  * feat: use arg_esp_path directly
  * fix: get esp_device from bootctl
  * fix: only install shim for secure boot
  * feat: create only non-existing entries & pass correct ESP partition
  * fix: make efibootmgr silent
  * feat: create boot menu entries when installed
* Mon Aug 14 2023 lnussel@suse.com
- Update to version 1+git20230814.38973c7:
  * Support purge-kernels
  * Fix postun
  * Remove debug logging
* Mon Aug  7 2023 Fabian Vogt <fvogt@suse.com>
- Only install the snapper plugin if sdbootutil is requested
- Bypass git, owner is not available ATM
* Thu Jul 27 2023 lnussel@suse.com
- Update to version 1+git20230727.a0e666f:
  * Set and honor $SYSTEMD_ESP_PATH
  * rpm-script: don't remove kernel on reinstalls
* Wed Jul 26 2023 lnussel@suse.com
- Update to version 1+git20230726.a994d2e:
  * Fix installing extra kernels in MicroOS
  * Replace file triggers with scriptlet
  * Fix cleanup of rollback files
  * Don't install unchanged files
  * Add is-bootable and list-kernels commands
  * Add ARCHITECTURE.md which explains how the setup works
  * Add default loader config when installed
* Mon Jul 17 2023 lnussel@suse.com
- Update to version 1+git20230717.dac075e:
  * Install default boot loader in non-secure-boot case too
* Thu Jul 13 2023 lnussel@suse.de
- Update to version 1+git20230713.df6eaca:
  * Update features
  * Call stty only in interactive mode
  * silence stty errors
* Thu Jul 13 2023 lnussel@suse.de
- Update to version 1+git20230713.356f0c5:
  * Fix rpm dependencies
* Tue Jul 11 2023 lnussel@suse.com
- Update to version 1+git20230711.f5c7e48:
  * Fix setting root and rootflags
* Tue Jul 11 2023 lnussel@suse.com
- Update to version 1+git20230626.1ef6b4d:
  * creating /etc/kernel directory
  * Update help screen
* Thu Jun 15 2023 lnussel@suse.de
- Update to version 1+git20230615.587e134:
  * Handle out of space
* Thu Jun 15 2023 Ludwig Nussel <lnussel@suse.de>
- initial package
